trackc - track view of chromosome conformation and multi-omics data
===================================================================

**trackc** is a Python Package to Flexible Visualization of 3D Genome and Multiomics.
It builds on top of `matplotlib`, from which it allows for flexible adjustments.

TrackC's key applications
--------------------------
- Mark the abnormal interaction formed by the structural variation of the genome.
- Show the three-dimensional genome interaction and multi-omics data after rearrangement.
- Flexible and convenient layout for multi-track 

Getting started with trackc
----------------------------
- Browse :doc:`tutorials </tutorials>`, :doc:`available tracks types </available_track_types>` and :doc:`gallery </gallery>`.


Contributing to trackc
-----------------------
We are happy about any contributions! Welcome to talk at github issue.

.. toctree::
   :caption: General:
   :maxdepth: 1

   install
   tutorials
   gallery
   api
   others
   developer/index
   

.. _github: https://github.com/seqyuan/trackc


Citation
---------

Please cite trackc as follows:

**trackc: a Package for Flexible Visualization of rearrangement 3D Genome and Multi-omics**
